import PuppeteerBrowser from "./components/Puppeteer";
import chokidar from "chokidar";
import path from "path";
import "log-timestamp";

export type config = {
    urls: Array<string>;
    bundlePath?: string;
    extensionsPath?: string;
    credentials?: null | {
        user: string;
        password: string;
    };
    disableRefresh?: boolean;
    disableExtensions?: boolean;
    waitUntil?: "load" | "domcontentloaded" | "networkidle0" | "networkidle2";
};

class Index {

    constructor(
        private browserInstance: PuppeteerBrowser,
        private bundlePath: string | null = null,
    ) {
        this.launch();
    };

    static async build(config: config) {
        let browserInstance = await PuppeteerBrowser.build(config);
        return new Index(browserInstance, config.bundlePath);
    };

    private async launch() {
        const self = this;
        await self.browserInstance.start();
        const watcher = chokidar.watch(this.bundlePath || path.resolve(process.cwd() + "/dist/"), { ignored: /^\./, persistent: true });
        watcher
            .on('change', function (path: any) {
                self.browserInstance.reloadTab();
                console.log('File', path, 'has been updated');
            })
            .on('error', function (error: any) { console.error('Error happened', error); })
        // .on('unlink', function(path) {console.log('File', path, 'has been removed');})
        // .on('add', function(path) {console.log('File', path, 'has been added');})
    }

    public reloadChanges = async () => {
        this.browserInstance.reloadTab();
    }
}

export default Index;